# GLAcier Feature Tracking testkit: `glaft`

A Python package for assessing and benchmarking feature-tracked glacier velocity maps derived from satellite imagery. Includes demo Notebook examples using data from Kaskawulsh glacier, Canada. See our [user manual](https://whyjz.github.io/GLAFT/doc/introduction.html) for more information.

[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/whyjz/GLAFT/master?labpath=doc%2Fquickstart.ipynb)

## Installation

**Try GLAFT without installing**: We recommend running our [Quick Start notebook on MyBinder.org](https://mybinder.org/v2/gh/whyjz/glacier-ft-test/master?urlpath=tree/jupyter-book/doc/quickstart.ipynb).

**For cloud access**: We recommend using the [Ghub portal to launch GLAFT](https://theghub.org/tools/glaft/status) (registration required).

**For local installation**: GLAFT is available on PyPI and can be installed via `pip`. 

```
pip install glaft
```

## License

GLAFT uses the [MIT License](https://github.com/whyjz/GLAFT/blob/master/LICENSE).

Contribution is always welcome!